/*
 * MySQLClient.h
 *
 *  Created on: 14 Μαρ 2012
 *      Author: nick
 */

#ifndef MYSQLCLIENT_H_
#define MYSQLCLIENT_H_

#include "lwip/ip_addr.h"

#define MYSQL_DEBUG  DBG_OFF

typedef unsigned char byte;

#define COM_QUERY	0x03           // mysql_real_query

///MySQL client results
enum MySQLResult
{
   MYSQL_OK, ///<Success
   MYSQL_PROCESSING, ///<Processing
   MYSQL_PRTCL, ///<Protocol error
   MYSQL_SETUP, ///<Not properly configured
   MYSQL_DNS, ///<Could not resolve name
   MYSQL_AUTHFAILED, ///<Auth failure
   MYSQL_READY, ///<Ready to send commands
   MYSQL_SQL, ///<SQL Error
   MYSQL_TIMEOUT, ///<Connection timeout
   MYSQL_CONN ///<Connection error
};

///Opens a connection to a server
/**
Opens a connection to the server host using the provided username, password passowrd and selecting database
On completion of this call (and any further one), the callback set in parameter is fired with the result of that command in parameter
@param host : server
@param user : username
@param db : database to use
@param pMethod : callback to call on each request completion
*/
struct netconn *MySqlOpen(struct netif *net_eth,char *host, const char *user, const char *password, const char *db, void (*pMethod)(enum MySQLResult)); //Non blocking


///Executes an SQL command
/**
Executes an SQL request on the SQL server
This is a non-blocking function
On completion, the callback set in the open function is fired with the result of the command in parameter
@param sqlCommand SQL request to execute
*/
enum MySQLResult MySqlExecute(struct netconn *conn, byte command, char *arg, int len);
int MySqlCommand(struct netconn *conn, byte command, int len);
int MySqlSend(struct netconn *conn, byte *data, int len);
///Closes the connection to the server
int MySqlExit(struct netconn *conn);

void setOnResult( void (*pMethod)(enum MySQLResult) );

#endif /* MYSQLCLIENT_H_ */
